@@ -10,12 +10,12 @@ use File::Spec; #not really needed because File::Copy already gets it, but for g
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(fcopy rcopy dircopy fmove rmove dirmove pathmk pathrm pathempty pathrmdir);
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 our $MaxDepth = 0;
 our $KeepMode = 1;
 our $CPRFComp = 0; 
-our $CopyLink = eval { symlink '',''; 1 } || 0;
+our $CopyLink = eval { local $SIG{'__DIE__'};symlink '',''; 1 } || 0;
 our $PFSCheck = 1;
 our $RemvBase = 0;
 our $NoFtlPth = 0;
@@ -26,6 +26,8 @@ our $RMTrgDir = 0;
 our $CondCopy = {};
 
 my $samecheck = sub {
+   return if $^O eq 'MSWin32'; # need better way to check for this on winders...
+
    my $one = '';
    if($PFSCheck) {
       $one    = join( '-', ( stat $_[0] )[0,1] ) || '';
@@ -102,7 +104,9 @@ sub fcopy {
    if($path && !-d $path) {
       pathmk(File::Spec->catpath($volm,$path), $NoFtlPth);
    }
-   if(-l $_[0] && $CopyLink) {
+   if(-l $_[0] && ($CopyLink || !-e readlink($_[0])) ) {
+      carp "Copying a symlink ($_[0]) whose target does not exist" 
+          if !-e readlink($_[0]);
       symlink readlink(shift()), shift() or return;
    } else {  
       copy(@_) or return;
@@ -175,7 +179,9 @@ sub dircopy {
           my ($file_ut) = $file =~ m{ (.*) }xms;
           my $org = File::Spec->catfile($str, $file_ut);
           my $new = File::Spec->catfile($end, $file_ut);
-          if(-l $org && $CopyLink) {
+          if(-l $org && ($CopyLink || !-e readlink($_[0])) ) {
+              carp "Copying a symlink ($_[0]) whose target does not exist" 
+                  if !-e readlink($_[0]);
               symlink readlink($org), $new or return;
           } 
           elsif(-d $org) {
@@ -522,6 +528,9 @@ This is false by default so that a check is done to see if the source directory
 
 If you ever find a situation where $CopyLoop = 1 is desirable let me know (IE its a bad bad idea but is there if you want it)
 
+(Note: On Windows this was necessary since it uses stat() to detemine samedness and stat() is essencially useless for this on Windows. 
+The test is now simply skipped on Windows but I'd rather have an actual reliable check if anyone in Microsoft land would care to share)
+
 =head1 SEE ALSO
 
 L<File::Copy> L<File::Spec>
